==> jquery-cropper-1.0.2.tgz: jquery-cropper/README.md <==
# Installation
> `npm install --save @types/jquery-cropper`

# Summary
This package contains type definitions for jquery-cropper (https://github.com/fengyuanchen/jquery-cropper).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-cropper.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-cropper/index.d.ts)
````ts
// Type definitions for jquery-cropper 1.0
// Project: https://github.com/fengyuanchen/jquery-cropper
// Definitions by: Mustafa Salaheldin <https://github.com/mustafasalahuldin>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.3

/// <reference types="jquery"/>

interface CropperOptions {
    viewMode?: number | undefined;
    dragMode?: string | undefined;
    initialAspectRatio?: number | undefined;
    aspectRatio?: number | undefined;
    data?: any;
    preview?: any;
    responsive?: boolean | undefined;
    restore?: boolean | undefined;
    checkCrossOrigin?: boolean | undefined;
    checkOrientation?: string | undefined;
    modal?: boolean | undefined;
    guides?: boolean | undefined;
    center?: boolean | undefined;
    highlight?: boolean | undefined;
    background?: boolean | undefined;
    autoCrop?: boolean | undefined;
    autoCropArea?: number | undefined;
    movable?: boolean | undefined;
    rotatable?: boolean | undefined;
    scalable?: boolean | undefined;
    zoomable?: boolean | undefined;
    zoomOnTouch?: boolean | undefined;
    zoomOnWheel?: boolean | undefined;
    wheelZoomRatio?: number | undefined;
    cropBoxMovable?: number | undefined;
    cropBoxResizable?: number | undefined;
    toggleDragModeOnDblclick?: number | undefined;
    minContainerWidth?: number | undefined;
    minContainerHeight?: number | undefined;
    minCanvasWidth?: number | undefined;
    minCanvasHeight?: number | undefined;
    minCropBoxWidth?: number | undefined;
    minCropBoxHeight?: number | undefined;
    ready?(): any;
    cropstart?(): any;
    cropmove?(): any;
    cropend?(): any;
    crop?(data?: any): void;
    zoom?(): any;
}

interface JQuery {
    cropper(options?: CropperOptions): JQuery;
    cropper(method: string, ...arguments: any[]): JQuery;
    selector: JQuery;
}

````

### Additional Details
 * Last updated: Thu, 08 Jul 2021 14:23:39 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)
 * Global values: none

# Credits
These definitions were written by [Mustafa Salaheldin](https://github.com/mustafasalahuldin).

==> jquery-cropper-1.0.3.tgz: jquery-cropper/README.md <==
# Installation
> `npm install --save @types/jquery-cropper`

# Summary
This package contains type definitions for jquery-cropper (https://github.com/fengyuanchen/jquery-cropper).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-cropper.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-cropper/index.d.ts)
````ts
/// <reference types="jquery"/>

interface CropperOptions {
    viewMode?: number | undefined;
    dragMode?: string | undefined;
    initialAspectRatio?: number | undefined;
    aspectRatio?: number | undefined;
    data?: any;
    preview?: any;
    responsive?: boolean | undefined;
    restore?: boolean | undefined;
    checkCrossOrigin?: boolean | undefined;
    checkOrientation?: string | undefined;
    modal?: boolean | undefined;
    guides?: boolean | undefined;
    center?: boolean | undefined;
    highlight?: boolean | undefined;
    background?: boolean | undefined;
    autoCrop?: boolean | undefined;
    autoCropArea?: number | undefined;
    movable?: boolean | undefined;
    rotatable?: boolean | undefined;
    scalable?: boolean | undefined;
    zoomable?: boolean | undefined;
    zoomOnTouch?: boolean | undefined;
    zoomOnWheel?: boolean | undefined;
    wheelZoomRatio?: number | undefined;
    cropBoxMovable?: number | undefined;
    cropBoxResizable?: number | undefined;
    toggleDragModeOnDblclick?: number | undefined;
    minContainerWidth?: number | undefined;
    minContainerHeight?: number | undefined;
    minCanvasWidth?: number | undefined;
    minCanvasHeight?: number | undefined;
    minCropBoxWidth?: number | undefined;
    minCropBoxHeight?: number | undefined;
    ready?(): any;
    cropstart?(): any;
    cropmove?(): any;
    cropend?(): any;
    crop?(data?: any): void;
    zoom?(): any;
}

interface JQuery {
    cropper(options?: CropperOptions): JQuery;
    cropper(method: string, ...arguments: any[]): JQuery;
    selector: JQuery;
}

````

### Additional Details
 * Last updated: Wed, 18 Oct 2023 05:47:07 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)

# Credits
These definitions were written by [Mustafa Salaheldin](https://github.com/mustafasalahuldin).
